Skip to contents

Adds Movebank data (reference-data, gps, acceleration, accessory-measurements) as a Data Resource to a Data Package. The function extends frictionless::add_resource() by adding the following to the Table Schema of the resource:

  • The title, definition, format and URI for each field, from the latest version of the Movebank Attribute Dictionary.

  • The primary key of the resource and foreign keys between resources.

Usage

add_resource(package, resource_name, files, keys = TRUE)

Arguments

package

Data Package object, as returned by read_package() or create_package().

resource_name

Name of the Data Resource.

files

One or more paths to CSV file(s) that contain the data for this resource, as a character (vector).

keys

If TRUE, primaryKey and foreignKey properties are added to the Table Schema.

Value

package with one additional resource.

Details

See vignette("movepub") for examples.